:html_theme.sidebar_secondary.remove:

#####
Safir
#####

Safir is Rubin Observatory's library for building FastAPI_ services for Phalanx_ Kubernetes clusters, including the Rubin Science Platform and Roundtable.
Safir is developed, maintained, and field tested by the SQuaRE team.

Safir is developed on GitHub at https://github.com/lsst-sqre/safir and is available on PyPI_.

User guide
==========

.. toctree::
   :maxdepth: 2

   user-guide/index

API
===

.. toctree::
   :maxdepth: 2

   api

.. toctree::
   :maxdepth: 1
   :hidden:

   changelog

Development guide
=================

.. toctree::
   :maxdepth: 2

   dev/index
